// Copyright (c) 2022 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "SimpleVNScene.hpp"

namespace Dawn {
  class TestScene : public SimpleVNScene {
    protected:
      void vnStage() override {
        SimpleVNScene::vnStage();

        // Poker Test
        auto pokerGameItem = this->createSceneItem();
        auto pokerGame = pokerGameItem->addComponent<PokerGame>();

        for(int32_t i = 0; i < 5; i++) {
          auto player = VNPenny::create(this);

          auto uiPlayer = canvas->addElement<PokerPlayerDisplay>();
          uiPlayer->setTransform(UI_COMPONENT_ALIGN_START, UI_COMPONENT_ALIGN_START, glm::vec4(i * 220, 0, 220, 200), 0);
          uiPlayer->setPlayer(player->getComponent<PokerPlayer>());
        }
        

      }

      IVisualNovelEvent * getVNEvent() override {
        auto texture = this->game->assetManager.get<TextureAsset>("texture_tavern_night");

        auto start = new VisualNovelChangeSimpleBackgroundEvent(
          vnManager, &texture->texture
        );

        start
          ->then(new VisualNovelPauseEvent(vnManager, 1.0f))
          ->then(new VisualNovelFadeEvent(
            vnManager, COLOR_BLACK, false, &easeOutCubic, 1.0f
          ))
          ->then(new VisualNovelTextboxEvent(vnManager, "Starting Game"))
          ->then(new PokerNewGameEvent(vnManager))
          ->then(new VisualNovelTextboxEvent(vnManager, "Game Started"))
          ->then(new PokerInitialEvent(vnManager))
        ;

        return start;
      }

    public:
      TestScene(DawnGame *game) : SimpleVNScene(game) {

      }

      std::vector<Asset*> getRequiredAssets() override {
        auto assMan = &this->game->assetManager;
        std::vector<Asset*> assets;
        vectorAppend(&assets, &SimpleVNScene::getRequiredAssets());
        assets.push_back(assMan->get<TextureAsset>("texture_tavern_night"));
        return assets;
      }
  };
}